pub struct GetNFTIndexResponse {
pub index: u64,
}Fields
index: u64Trait Implementations
Sourceimpl Clone for GetNFTIndexResponse
impl Clone for GetNFTIndexResponse
Sourcefn clone(&self) -> GetNFTIndexResponse
fn clone(&self) -> GetNFTIndexResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetNFTIndexResponse
impl Debug for GetNFTIndexResponse
Sourceimpl<'de> Deserialize<'de> for GetNFTIndexResponse
impl<'de> Deserialize<'de> for GetNFTIndexResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetNFTIndexResponse
impl JsonSchema for GetNFTIndexResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GetNFTIndexResponse
impl PartialEq for GetNFTIndexResponse
Sourceimpl Serialize for GetNFTIndexResponse
impl Serialize for GetNFTIndexResponse
impl StructuralPartialEq for GetNFTIndexResponse